==> app_state-0.7.2.tar.gz: example/README.md <==
The gallery of runnable examples is here: https://github.com/alexeyinkin/flutter-app-state-examples

## 1. Bare Minimal App

This app does nothing.

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/1_min

![Bare Minimal App](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/img/minimal.png)



## 2. The Book List App Without URLs

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/2_two_screens

![Book List No URLs](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/img/book-list-no-urls.gif)



## 3. The Book List App With URLs

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/3_web

![Book List With URLs](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/img/book-list-urls.gif)



## 4. Tabs with Independent Navigation Stacks

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/4_tabs

![Tabs with Independent Navigation Stacks](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/img/multiple-stacks.gif)



## 5. Receiving the Dialog Result after the App Restart

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/5_route_result

![Receiving the Dialog Result after the App Restart](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/img/result-surviving-restart.gif)



## 6. Recovering Unsaved Input on Back and Forward Navigation

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/6_forward_recovery

![Recovering Unsaved Input on Back and Forward Navigation](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/img/recovering-unsaved-input.gif)


## 7. Pushing one pop-up screen to any tab

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/7_any_tab

![Recovering Unsaved Input on Back and Forward Navigation](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/img/any-tab-anywhere.gif)


## 8. Using enum_map package for higher compile-time safety of tabs

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/8_enum_map


## 9. Using BLoC, Cubit, and ChangeNotifier for state management of pages

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/9_state

==> app_state-0.7.4.tar.gz: example/README.md <==
The gallery of runnable examples is here: https://github.com/alexeyinkin/flutter-app-state-examples

## 1. Bare Minimal App

This app does nothing.

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/1_min

![Bare Minimal App](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/app_state/img/minimal.png)



## 2. The Book List App Without URLs

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/2_two_screens

![Book List No URLs](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/app_state/img/book-list-no-urls.gif)



## 3. The Book List App With URLs

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/3_web

![Book List With URLs](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/app_state/img/book-list-urls.gif)



## 4. Tabs with Independent Navigation Stacks

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/4_tabs

![Tabs with Independent Navigation Stacks](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/app_state/img/multiple-stacks.gif)



## 5. Receiving the Dialog Result after the App Restart

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/5_route_result

![Receiving the Dialog Result after the App Restart](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/app_state/img/result-surviving-restart.gif)



## 6. Recovering Unsaved Input on Back and Forward Navigation

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/6_forward_recovery

![Recovering Unsaved Input on Back and Forward Navigation](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/app_state/img/recovering-unsaved-input.gif)


## 7. Pushing one pop-up screen to any tab

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/7_any_tab

![Recovering Unsaved Input on Back and Forward Navigation](https://raw.githubusercontent.com/alexeyinkin/flutter-app-state/main/app_state/img/any-tab-anywhere.gif)


## 8. Using enum_map package for higher compile-time safety of tabs

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/8_enum_map


## 9. Using BLoC, Cubit, and ChangeNotifier for state management of pages

Runnable project: https://github.com/alexeyinkin/flutter-app-state/tree/main/app_state/example/lib/9_state
